@@ -1,9 +1,13 @@
 try:
     from zcrmsdk.src.com.zoho.crm.api.util.header_param_validator import HeaderParamValidator
     from zcrmsdk.src.com.zoho.crm.api.header import Header
+    from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
+    from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
 except Exception:
     from .util import HeaderParamValidator
     from .header import Header
+    from ..api.exception import SDKException
+    from ..api.util import Constants
 
 
 class HeaderMap(object):
@@ -27,15 +31,25 @@ class HeaderMap(object):
             value (object): An object containing the header value.
         """
 
-        name = header.name
+        if header is None:
+            raise SDKException(Constants.HEADER_NONE_ERROR, Constants.HEADER_INSTANCE_NONE_ERROR)
+
+        header_name = header.name
+
+        if header_name is None:
+            raise SDKException(Constants.HEADER_NAME_NONE_ERROR, Constants.HEADER_NAME_NULL_ERROR_MESSAGE)
+
+        if value is None:
+            raise SDKException(Constants.HEADER_NONE_ERROR, header_name + Constants.NONE_VALUE_ERROR_MESSAGE)
+
         class_name = header.class_name
 
         if class_name is not None:
             value = HeaderParamValidator().validate(header, value)
 
-        if name not in self.header_map:
-            self.header_map[name] = str(value)
+        if header_name not in self.header_map:
+            self.header_map[header_name] = str(value)
 
         else:
-            header_value = self.header_map[name]
-            self.header_map[name] = header_value + ',' + str(value)
+            header_value = self.header_map[header_name]
+            self.header_map[header_name] = header_value + ',' + str(value)
