@@ -11,7 +11,8 @@ try:
     from zcrmsdk.src.com.zoho.crm.api.dc.data_center import DataCenter
     from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
     from zcrmsdk.src.com.zoho.api.authenticator.token import Token
-    from zcrmsdk.src.com.zoho.crm.api.logger import Logger, SDKLogger
+    from zcrmsdk.src.com.zoho.api.logger import Logger, SDKLogger
+    from zcrmsdk.src.com.zoho.crm.api.user_proxy import UserProxy
 
 except Exception:
     import logging
@@ -26,6 +27,7 @@ except Exception:
     from ..api.util.constants import Constants
     from ...api.authenticator.token import Token
     from ...api.logger import Logger, SDKLogger
+    from .user_proxy import UserProxy
 
 
 class Initializer(object):
@@ -34,19 +36,22 @@ class Initializer(object):
     The class to initialize Zoho CRM SDK.
     """
 
+    def __init__(self):
+        self.environment = None
+        self.user = None
+        self.store = None
+        self.token = None
+        self.auto_refresh_fields = None
+        self.user_proxy = None
+        self.resource_path = None
+
     json_details = None
-    environment = None
-    user = None
-    store = None
-    token = None
-    auto_refresh_fields = None
-    resource_path = None
     initializer = None
     LOCAL = threading.local()
     LOCAL.init = None
 
     @staticmethod
-    def initialize(user, environment, token, store, logger, auto_refresh_fields, resource_path):
+    def initialize(user, environment, token, store, auto_refresh_fields, resource_path, logger=None, proxy=None):
 
         """
         The method to initialize the SDK.
@@ -56,9 +61,10 @@ class Initializer(object):
             environment (DataCenter.Environment) : An Environment class instance containing the CRM API base URL and Accounts URL.
             token (Token) : A Token class instance containing the OAuth client application information.
             store (TokenStore) : A TokenStore class instance containing the token store information.
-            logger (Logger): A Logger class instance containing the log file path and Logger type.
             auto_refresh_fields (bool) : A Boolean value to allow or prevent auto-refreshing of the modules' fields in the background.
             resource_path (str) : A String containing the absolute directory path to store user specific JSON files containing module fields information.
+            logger (Logger): A Logger class instance containing the log file path and Logger type.
+            proxy (UserProxy) : An UserProxy class instance containing the proxy properties of the user.
         """
 
         try:
@@ -89,11 +95,16 @@ class Initializer(object):
             if resource_path is None or len(resource_path) == 0:
                 raise SDKException(Constants.INITIALIZATION_ERROR, Constants.RESOURCE_PATH_ERROR_MESSAGE)
 
+            if proxy is not None and not isinstance(proxy, UserProxy):
+                error = {Constants.FIELD: Constants.USER_PROXY, Constants.EXPECTED_TYPE: UserProxy.__module__}
+
+                raise SDKException(Constants.INITIALIZATION_ERROR, Constants.INITIALIZATION_EXCEPTION, details=error)
+
             if logger is not None:
-                SDKLogger.initialize(logger.level, logger.file_path)
+                SDKLogger.initialize(logger)
 
             else:
-                SDKLogger.initialize(Logger.Levels.INFO, os.path.join(os.getcwd(), Constants.LOGFILE_NAME))
+                SDKLogger.initialize(Logger(Logger.Levels.INFO, os.path.join(os.getcwd(), Constants.LOGFILE_NAME)))
 
             initializer = Initializer()
 
@@ -103,6 +114,7 @@ class Initializer(object):
             initializer.store = store
             initializer.auto_refresh_fields = auto_refresh_fields
             initializer.resource_path = resource_path
+            initializer.user_proxy = proxy
 
             Initializer.initializer = initializer
 
@@ -144,7 +156,7 @@ class Initializer(object):
         return file_contents
 
     @staticmethod
-    def switch_user(user, environment, token, auto_refresh_fields):
+    def switch_user(user, environment, token, auto_refresh_fields, proxy=None):
 
         """
         The method to switch the different user in SDK environment.
@@ -154,8 +166,33 @@ class Initializer(object):
             environment (DataCenter.Environment) : An Environment class instance containing the CRM API base URL and Accounts URL.
             token (Token) : A Token class instance containing the OAuth client application information.
             auto_refresh_fields (bool) : A Boolean value to allow or prevent auto-refreshing of the modules' fields in the background.
+            proxy (UserProxy) : An UserProxy class instance containing the proxy properties of the user.
         """
 
+        if not isinstance(user, UserSignature):
+            error = {Constants.FIELD: Constants.USER, Constants.EXPECTED_TYPE: UserSignature.__module__}
+
+            raise SDKException(Constants.SWITCH_USER_ERROR, Constants.SWITCH_USER_EXCEPTION, details=error)
+
+        if not isinstance(environment, DataCenter.Environment):
+            error = {Constants.FIELD: Constants.ENVIRONMENT,
+                     Constants.EXPECTED_TYPE: DataCenter.Environment.__module__}
+
+            raise SDKException(Constants.SWITCH_USER_ERROR, Constants.SWITCH_USER_EXCEPTION, details=error)
+
+        if not isinstance(token, Token):
+            error = {Constants.FIELD: Constants.TOKEN, Constants.EXPECTED_TYPE: Token.__module__}
+
+            raise SDKException(Constants.SWITCH_USER_ERROR, Constants.SWITCH_USER_EXCEPTION, details=error)
+
+        if auto_refresh_fields is None:
+            raise SDKException(Constants.SWITCH_USER_ERROR, Constants.AUTO_REFRESH_FIELDS_ERROR_MESSAGE)
+
+        if proxy is not None and not isinstance(proxy, UserProxy):
+            error = {Constants.FIELD: Constants.USER_PROXY, Constants.EXPECTED_TYPE: UserProxy.__module__}
+
+            raise SDKException(Constants.SWITCH_USER_ERROR, Constants.SWITCH_USER_EXCEPTION, details=error)
+
         initializer = Initializer()
 
         initializer.user = user
@@ -164,6 +201,7 @@ class Initializer(object):
         initializer.auto_refresh_fields = auto_refresh_fields
         initializer.store = Initializer.initializer.store
         initializer.resource_path = Initializer.initializer.resource_path
+        initializer.user_proxy = proxy
 
         Initializer.LOCAL.init = initializer
 
