@@ -1,9 +1,11 @@
 from .action_wrapper import ActionWrapper
 from .api_exception import APIException
 from .note import Note
+from .response_handler import ResponseHandler
 from .action_response import ActionResponse
 from .success_response import SuccessResponse
-from .notes_operations import NotesOperations
+from .notes_operations import NotesOperations, GetNotesParam, GetNotesHeader, DeleteNotesParam
 from .response_wrapper import ResponseWrapper
-from .details import Details
 from .body_wrapper import BodyWrapper
+from .action_handler import ActionHandler
+from .info import Info
