@@ -1,9 +1,13 @@
 try:
     from zcrmsdk.src.com.zoho.crm.api.util.header_param_validator import HeaderParamValidator
     from zcrmsdk.src.com.zoho.crm.api.param import Param
+    from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
+    from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
 except Exception:
     from .util import HeaderParamValidator
     from .param import Param
+    from ..api.exception import SDKException
+    from ..api.util import Constants
 
 
 class ParameterMap(object):
@@ -27,15 +31,25 @@ class ParameterMap(object):
             value (object): An object containing the parameter value.
         """
 
-        name = param.name
+        if param is None:
+            raise SDKException(Constants.PARAMETER_NONE_ERROR, Constants.PARAM_INSTANCE_NONE_ERROR)
+
+        param_name = param.name
+        
+        if param_name is None:
+            raise SDKException(Constants.PARAM_NAME_NONE_ERROR, Constants.PARAM_NAME_NONE_ERROR_MESSAGE)
+
+        if value is None:
+            raise SDKException(Constants.PARAMETER_NONE_ERROR, param_name + Constants.NONE_VALUE_ERROR_MESSAGE)
+
         class_name = param.class_name
 
         if class_name is not None:
             value = HeaderParamValidator().validate(param, value)
 
-        if name not in self.parameter_map:
-            self.parameter_map[name] = str(value)
+        if param_name not in self.parameter_map:
+            self.parameter_map[param_name] = str(value)
 
         else:
-            parameter_value = self.parameter_map[name]
-            self.parameter_map[name] = parameter_value + ',' + str(value)
+            parameter_value = self.parameter_map[param_name]
+            self.parameter_map[param_name] = parameter_value + ',' + str(value)
