@@ -145,7 +145,7 @@ class APIException(ResponseHandler, ActionResponse, ActionHandler, DeletedRecord
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
