@@ -19,7 +19,7 @@ class Territory(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -43,7 +43,7 @@ class Territory(object):
 		The method to get the include_child
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the include_child
 		"""
 
 		return self.__include_child
@@ -70,7 +70,7 @@ class Territory(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
