@@ -20,10 +20,10 @@ class ShareRecordsOperations(object):
 			record_id (int) : An int representing the record_id
 		"""
 
-		if module_api_name is not None and not isinstance(module_api_name, str):
+		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if record_id is not None and not isinstance(record_id, int):
+		if not isinstance(record_id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
 		
 		self.__module_api_name = module_api_name
