@@ -1,28 +1,22 @@
 try:
-    import logging
     import re
     import traceback
-    from zcrmsdk.src.com.zoho.api.exception.sdk_exception import SDKException
+    from zcrmsdk.src.com.zoho.crm.api.exception.sdk_exception import SDKException
     from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
 
 except Exception:
-    import logging
     import re
     import traceback
-    from ...api.exception.sdk_exception import SDKException
+    from zcrmsdk.src.com.zoho.crm.api.exception.sdk_exception import SDKException
     from .util.constants import Constants
 
 
 class UserSignature(object):
 
     """
-    The class representing the CRM user email.
+    This class represents the Zoho CRM User.
     """
 
-    logger = logging.getLogger('SDKLogger')
-
-    regex = Constants.EMAIL_REGEX
-
     def __init__(self, email):
 
         """
@@ -34,10 +28,10 @@ class UserSignature(object):
 
         error = {}
 
-        if re.search(UserSignature.regex, email) is None:
+        if re.search(Constants.EMAIL_REGEX, email) is None:
             error[Constants.FIELD] = Constants.EMAIL
             error[Constants.EXPECTED_TYPE] = Constants.EMAIL
 
-            raise SDKException(Constants.USER_ERROR, None, details=error, cause=traceback.format_stack(limit=6))
+            raise SDKException(Constants.USER_SIGNATURE_ERROR, details=error)
 
         self.email = email
