@@ -139,7 +139,7 @@ class JSONConverter(Converter):
                     else:
                         request_json[key_name] = self.set_data(member_detail, field_value)
 
-        if self.common_api_handler.mandatory_checker is not None and self.common_api_handler.mandatory_checker and not skip_mandatory:
+        if not skip_mandatory and self.common_api_handler.mandatory_checker is not None and self.common_api_handler.mandatory_checker:
             if self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_CREATE:
                 if lookup:
                     if len(primary_keys) > 0:
@@ -173,7 +173,7 @@ class JSONConverter(Converter):
                     raise SDKException(Constants.MANDATORY_VALUE_MISSING_ERROR, Constants.PRIMARY_KEY_MISSING_ERROR,
                                        error)
 
-        elif lookup and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE and not skip_mandatory:
+        elif not skip_mandatory and lookup and self.common_api_handler.category_method.upper() == Constants.REQUEST_CATEGORY_UPDATE:
             if len(primary_keys) > 0:
                 error = {
                     Constants.FIELD: class_member_name,
@@ -200,7 +200,7 @@ class JSONConverter(Converter):
                 Constants.SKIP_MANDATORY] if Constants.SKIP_MANDATORY in member_detail else False
             class_member_name = member_detail[Constants.NAME]
 
-        request_json, module_detail, unique_values = {}, {}, {}
+        request_json, module_detail = {}, {}
         module_api_name = self.common_api_handler.module_api_name
         class_name = record_instance.__class__.__name__
 
@@ -272,13 +272,10 @@ class JSONConverter(Converter):
                 if Constants.READ_ONLY in key_detail or (Constants.NAME not in key_detail):
                     continue
 
-                if self.value_checker(class_name, key_name, key_detail, key_value, unique_values, instance_number):
+                if self.value_checker(class_name, key_name, key_detail, key_value, self.unique_dict, instance_number):
                     if key_value is None:
                         self.mandatory_check(record_instance, key_name, key_detail, lookup, skip_mandatory)
 
-                    if Constants.PRIMARY in key_detail and key_detail[Constants.PRIMARY]:
-                        is_primary_key_added = True
-
                     json_value = self.set_data(key_detail, key_value)
 
             else:
