@@ -159,10 +159,16 @@ class Utility(object):
 
                     Utility.write_to_file(file_path=record_field_details_path, file_contents=record_field_details_json)
                 except Exception as ex:
-                    Utility.logger.info(Constants.EXCEPTION + ex.__str__())
+                    sdk_exception = SDKException(cause=ex)
+                    Utility.logger.error(Constants.EXCEPTION + sdk_exception.__str__())
+                    raise sdk_exception
 
+            if not isinstance(e, SDKException):
+                e = SDKException(cause=e)
             Utility.logger.info(Constants.EXCEPTION + e.__str__())
 
+            raise e
+
     @staticmethod
     def modify_fields(record_field_details_path, modified_time):
         modified_modules = Utility.get_modules(modified_time)
@@ -230,13 +236,22 @@ class Utility(object):
 
                     Utility.get_related_lists(related_module_name, module_api_name, common_api_handler)
 
+            except SDKException as e:
+                Utility.logger.error(Constants.EXCEPTION + e.__str__())
+                raise e
+
             except Exception as e:
-                Utility.logger.info(Constants.EXCEPTION + e.__str__())
+                sdk_exception = SDKException(cause=e)
+                Utility.logger.error(Constants.EXCEPTION + sdk_exception.__str__())
+                raise sdk_exception
 
     @staticmethod
     def check_related_list_exists(related_module_name, module_related_list_array, common_api_handler):
         for related_list_jo in module_related_list_array:
             if related_list_jo[Constants.API_NAME] is not None and related_list_jo[Constants.API_NAME].lower() == related_module_name.lower():
+                if related_list_jo[Constants.HREF] == Constants.NULL_VALUE:
+                    raise SDKException(code=Constants.UNSUPPORTED_IN_API, message=common_api_handler.http_method + ' ' + common_api_handler.api_path + Constants.UNSUPPORTED_IN_API_MESSAGE)
+
                 common_api_handler.module_api_name = related_list_jo[Constants.MODULE]
                 Utility.get_fields(related_list_jo[Constants.MODULE])
                 return True
@@ -267,9 +282,10 @@ class Utility(object):
                             Constants.API_NAME: related_list.get_api_name(),
                             Constants.MODULE: related_list.get_module(),
                             Constants.NAME: related_list.get_name(),
-                            Constants.HREF: related_list.get_href()
+                            Constants.HREF: related_list.get_href() if related_list.get_href() is not None else Constants.NULL_VALUE
                         }
                         related_list_array.append(related_list_detail)
+
                 elif isinstance(data_object, RelatedLists.APIException):
                     error_response = {
                         Constants.CODE: data_object.get_code().get_value(),
@@ -277,11 +293,13 @@ class Utility(object):
                         Constants.MESSAGE: data_object.get_message().get_value()
                     }
                     raise SDKException(Constants.API_EXCEPTION, None, error_response)
+
                 else:
                     error_response = {
                         Constants.CODE: response.get_status_code()
                     }
                     raise SDKException(Constants.API_EXCEPTION, None, error_response)
+
             else:
                 error_response = {
                     Constants.CODE: response.get_status_code()
@@ -307,10 +325,10 @@ class Utility(object):
             if response.get_status_code() == Constants.NO_CONTENT_STATUS_CODE:
                 return fields_details
 
-            data_object = response.get_object()
+            response_object = response.get_object()
 
-            if isinstance(data_object, Field.ResponseWrapper):
-                fields = data_object.get_fields()
+            if isinstance(response_object, Field.ResponseWrapper):
+                fields = response_object.get_fields()
 
                 for field in fields:
                     if field.get_api_name() in Constants.KEYS_TO_SKIP:
@@ -326,17 +344,31 @@ class Utility(object):
                     field_detail = {
                         Constants.NAME: Constants.LINE_TAX,
                         Constants.TYPE: Constants.LIST_NAMESPACE,
-                        Constants.STRUCTURE_NAME: Constants.LINETAX
+                        Constants.STRUCTURE_NAME: Constants.LINE_TAX_NAMESPACE
                     }
                     fields_details[Constants.LINE_TAX] = field_detail
-            else:
+
+                if module_api_name.lower() == Constants.NOTES:
+                    field_detail = {
+                        Constants.NAME: Constants.ATTACHMENTS,
+                        Constants.TYPE: Constants.LIST_NAMESPACE,
+                        Constants.STRUCTURE_NAME: Constants.ATTACHMENTS_NAMESPACE
+                    }
+                    fields_details[Constants.ATTACHMENTS] = field_detail
+
+            elif isinstance(response_object, Field.APIException):
                 error_response = {
-                    Constants.CODE: data_object.get_code().get_value(),
-                    Constants.STATUS: data_object.get_status().get_value(),
-                    Constants.MESSAGE: data_object.get_message().get_value()
+                    Constants.CODE: response_object.get_code().get_value(),
+                    Constants.STATUS: response_object.get_status().get_value(),
+                    Constants.MESSAGE: response_object.get_message().get_value()
                 }
                 raise SDKException(Constants.API_EXCEPTION, None, error_response)
 
+        else:
+            error_response = {
+                Constants.CODE: response.get_status_code()
+            }
+            raise SDKException(Constants.API_EXCEPTION, None, error_response)
         return fields_details
 
     @staticmethod
@@ -381,6 +413,20 @@ class Utility(object):
                     if module.get_api_supported():
                         api_names.append(module.get_api_name())
 
+            elif isinstance(response_object, Modules.APIException):
+                error_response = {
+                    Constants.CODE: response_object.get_code().get_value(),
+                    Constants.STATUS: response_object.get_status().get_value(),
+                    Constants.MESSAGE: response_object.get_message().get_value()
+                }
+                raise SDKException(Constants.API_EXCEPTION, None, error_response)
+
+        else:
+            error_response = {
+                Constants.CODE: response.get_status_code()
+            }
+            raise SDKException(Constants.API_EXCEPTION, None, error_response)
+
         return api_names
 
     @staticmethod
