@@ -33,7 +33,7 @@ class XMLConverter(Converter):
 
         self.common_api_handler = common_api_handler
 
-    def form_request(self, request_object, pack, instance_number):
+    def form_request(self, request_object, pack, instance_number, lookup, skip_mandatory):
 
         return None
 
